@@ -79,10 +79,18 @@ runExtractionPerPerson <- function(connection, cdmDatabaseSchema, ohdsiDatabaseS
     useMeasurementRangeGroupLongTerm = FALSE,
     useMeasurementRangeGroupMediumTerm = FALSE,
     useMeasurementRangeGroupShortTerm = TRUE,
+    useMeasurementValueAsConceptAnyTimePrior = FALSE,
+    useMeasurementValueAsConceptLongTerm = FALSE,
+    useMeasurementValueAsConceptMediumTerm = FALSE,
+    useMeasurementValueAsConceptShortTerm = TRUE,
     useObservationAnyTimePrior = FALSE,
     useObservationLongTerm = FALSE,
     useObservationMediumTerm = FALSE,
     useObservationShortTerm = TRUE,
+    useObservationValueAsConceptAnyTimePrior = FALSE,
+    useObservationValueAsConceptLongTerm = FALSE,
+    useObservationValueAsConceptMediumTerm = FALSE,
+    useObservationValueAsConceptShortTerm = TRUE,
     useCharlsonIndex = TRUE,
     useDcsi = TRUE,
     useChads2 = TRUE,
@@ -251,10 +259,18 @@ runExtractionAggregated <- function(connection, cdmDatabaseSchema, ohdsiDatabase
     useMeasurementRangeGroupLongTerm = FALSE,
     useMeasurementRangeGroupMediumTerm = FALSE,
     useMeasurementRangeGroupShortTerm = TRUE,
+    useMeasurementValueAsConceptAnyTimePrior = FALSE,
+    useMeasurementValueAsConceptLongTerm = FALSE,
+    useMeasurementValueAsConceptMediumTerm = FALSE,
+    useMeasurementValueAsConceptShortTerm = TRUE,
     useObservationAnyTimePrior = FALSE,
     useObservationLongTerm = FALSE,
     useObservationMediumTerm = FALSE,
     useObservationShortTerm = TRUE,
+    useObservationValueAsConceptAnyTimePrior = FALSE,
+    useObservationValueAsConceptLongTerm = FALSE,
+    useObservationValueAsConceptMediumTerm = FALSE,
+    useObservationValueAsConceptShortTerm = TRUE,
     useCharlsonIndex = TRUE,
     useDcsi = TRUE,
     useChads2 = TRUE,
@@ -376,7 +392,9 @@ runExtractionTemporalPerPerson <- function(connection, cdmDatabaseSchema, ohdsiD
     useMeasurement = TRUE,
     useMeasurementValue = TRUE,
     useMeasurementRangeGroup = TRUE,
+    useMeasurementValueAsConcept = TRUE,
     useObservation = TRUE,
+    useObservationValueAsConcept = TRUE,
     useCharlsonIndex = TRUE,
     useDcsi = TRUE,
     useChads2 = TRUE,
@@ -480,7 +498,9 @@ runExtractionTemporalAggregated <- function(connection, cdmDatabaseSchema, ohdsi
     useMeasurement = TRUE,
     useMeasurementValue = TRUE,
     useMeasurementRangeGroup = TRUE,
+    useMeasurementValueAsConcept = TRUE,
     useObservation = TRUE,
+    useObservationValueAsConcept = TRUE,
     useCharlsonIndex = TRUE,
     useDcsi = TRUE,
     useChads2 = TRUE,
